@@ -30,11 +30,9 @@
 #endif
 
 
-extern "C" {
 #include "RUtils.h"
 #include <Rinternals.h>
 #include <Rdefines.h>
-}
 
 #include <R_ext/Error.h>	/* for Rf_error and Rf_warning */
 
@@ -77,9 +75,9 @@ extern "C" {
 /* Parentheses added for FC4 with gcc4 and -D_FORTIFY_SOURCE=2 */
 #define PROBLEM			{char R_problem_buf[R_PROBLEM_BUFSIZE];(snprintf)(R_problem_buf, R_PROBLEM_BUFSIZE,
 #define MESSAGE                 {char R_problem_buf[R_PROBLEM_BUFSIZE];(snprintf)(R_problem_buf, R_PROBLEM_BUFSIZE,
-#define ERROR			),Rf_error(R_problem_buf);}
-#define RECOVER(x)		),Rf_error(R_problem_buf);}
-#define WARNING(x)		),Rf_warning(R_problem_buf);}
+#define ERROR			),Rf_error("%s", R_problem_buf);}
+#define RECOVER(x)		),Rf_error("%s", R_problem_buf);}
+#define WARNING(x)		),Rf_warning("%s", R_problem_buf);}
 #define LOCAL_EVALUATOR		/**/
 #define NULL_ENTRY		/**/
 #define WARN			WARNING(NULL)
